slepc-3.18.0 2022-10-01
Report Typos and Errors

# SVDGetType

Gets the SVD type as a string from the SVD object.

### Synopsis

    #include "slepcsvd.h"
    PetscErrorCode SVDGetType(SVD svd,SVDType *type)

Not Collective

### Input Parameter

| svd | - the singular value solver context

### Output Parameter

| type | - name of SVD method

### See Also

SVDSetType()

### Level

intermediate

### Location

src/svd/interface/svdbasic.c

### Examples

src/svd/tutorials/ex14.c.html
src/svd/tutorials/ex15.c.html
src/svd/tutorials/ex15f.F.html
src/svd/tutorials/ex45.c.html
Index of all SVD routines
Table of Contents for all manual pages
Index of all manual pages